import os
import os.path as path
from shutil import rmtree
from mock import Mock, patch

from ckan.common import config
import ckan.plugins.toolkit as toolkit

import ckanext.odsh.pdf_to_thumbnail.thumbnail as thumbnail


module_path = path.abspath(__file__)
dir_path = path.dirname(module_path)
resources_path = path.join(dir_path, 'resources')
temp_path = path.join(dir_path, 'temp_thumbnail')
thumbnail_folder = path.join(temp_path, 'thumbnail')


patch_get_resource_path = patch.object(
    thumbnail,
    'get_resource_path',
    return_value=os.path.join(resources_path, 'test_copy_pdf')
)


patch_get_filename_from_context = patch.object(
    thumbnail,
    '_get_filename_from_context',
    return_value='some_thumbnail.jpg'
)


patch_create_thumbnail_from_memory = patch.object(
    thumbnail,
    '_create_thumbnail_from_memory',
    return_value=(True, 'filename'),
)


patch_random_generator = patch.object(
    thumbnail,
    'b2a_hex',
    return_value='some_random',
)


mock_action_handler = Mock()
patch_get_action = patch.object(
    toolkit, 'get_action', return_value=mock_action_handler)


patch_create_thumbnail = patch.object(
    thumbnail, 'create_thumbnail',
    side_effect=[(True, 'filename'), ]
)


patch_write_thumbnail_into_package = patch.object(
    thumbnail, '_write_thumbnail_into_package')


patch_remove_thumbnail = patch.object(thumbnail, 'remove_thumbnail')


patch_get_package_dict_from_context = patch.object(thumbnail, '_get_package_dict_from_context',
                                                   return_value={})


patch_is_pdf = patch.object(thumbnail, '_is_pdf', return_value=True)


class WithTempFolder(object):

    def setUp(self):
        config.update({
            'ckan.thumbnail.size.width': 410,
            'ckan.storage_path': temp_path,
        })
        if not path.exists(temp_path):
            os.mkdir(temp_path)
            if not path.exists(thumbnail_folder):
                os.mkdir(thumbnail_folder)

    def tearDown(self):
        config.clear()
        rmtree(temp_path)


class WithAfterCreateDataFrontend(object):

    def setUp(self):
        config.update({
            'ckan.thumbnail.size.width': 410,
            'ckan.storage_path': temp_path,
        })

        # trapped in plugin.py
        self.resource = {
            u'cache_last_updated': None,
            u'cache_url': None,
            u'created': '2020-05-14T12:34:19.974216',
            u'datastore_active': False,
            u'description': u'',
            u'format': u'PDF',
            u'hash': u'',
            u'id': u'3ec53c20-f038-4ad6-a9fd-265cbe6faa27',
            u'last_modified': '2020-05-14T12:34:19.817460',
            u'mimetype': u'application/pdf',
            u'mimetype_inner': None,
            u'name': u'Checkliste-Barrierefreies-PDF.pdf',
            u'package_id': u'ff55a3ee-6dcd-4f76-b5a3-08055d5241f4',
            u'position': 0,
            u'resource_type': None,
            u'revision_id': u'0c3b309e-5179-4b4d-91f6-26221bba85e1',
            u'size': 112437L,
            u'state': u'active',
            u'url': u'http://192.168.152.133:5000/dataset/ff55a3ee-6dcd-4f76-b5a3-08055d5241f4/resource/3ec53c20-f038-4ad6-a9fd-265cbe6faa27/download/checkliste-barrierefreies-pdf.pdf',
            u'url_type': u'upload'
        }
        self.context = {
            'package': Mock(
                id=u'ff55a3ee-6dcd-4f76-b5a3-08055d5241f4',
                is_private=False,
                private=False,
                type=u'dataset',
                url=None,
            ),
            'resources': [
                Mock(
                    id=u'3ec53c20-f038-4ad6-a9fd-265cbe6faa27',
                    url_type=u'upload',
                )
            ]
        }

        # return value of resources_of_containing_package
        self.resources = [
            {
                u'cache_last_updated': None,
                u'cache_url': None,
                u'created': '2020-05-14T12:34:19.974216',
                u'datastore_active': False,
                u'description': u'',
                u'format': u'PDF',
                u'hash': u'',
                u'id': u'3ec53c20-f038-4ad6-a9fd-265cbe6faa27',
                u'last_modified': '2020-05-14T12:34:19.817460',
                u'mimetype': u'application/pdf',
                u'mimetype_inner': None,
                u'name': u'Checkliste-Barrierefreies-PDF.pdf',
                u'package_id': u'ff55a3ee-6dcd-4f76-b5a3-08055d5241f4',
                u'position': 0,
                u'resource_type': None,
                u'revision_id': u'0c3b309e-5179-4b4d-91f6-26221bba85e1',
                u'revision_timestamp': u'2020-05-14T12:34:19.950162',
                u'size': 112437L,
                u'state': u'active',
                u'url': u'http://192.168.152.133:5000/dataset/ff55a3ee-6dcd-4f76-b5a3-08055d5241f4/resource/3ec53c20-f038-4ad6-a9fd-265cbe6faa27/download/checkliste-barrierefreies-pdf.pdf',
                u'url_type': u'upload'
            }
        ]

        # return value of _get_package_dict_from_context
        self.package_dict = {
            'author': None,
            'author_email': None,
            'creator_user_id': u'ff8d002d-3908-45e5-ba7b-445381860957',
            'extras': [{u'key': u'groups', u'value': u''},
                       {u'key': u'issued', u'value': u'2020-05-14T00:00:00'},
                       {u'key': u'licenseAttributionByText', u'value': u''},
                       {u'key': u'spatial',
                        u'value': u'{"type": "Polygon", "coordinates": [[[9.5557, 54.6361], [9.5576, 54.6395], [9.5739, 54.6428], [9.593, 54.6508], [9.6041, 54.6497], [9.6049, 54.6533], [9.6132, 54.6556], [9.6261, 54.6632], [9.627, 54.6671], [9.6349, 54.6672], [9.6264, 54.6548], [9.6257, 54.6494], [9.6235, 54.6496], [9.624, 54.6426], [9.619, 54.6349], [9.6231, 54.6354], [9.6222, 54.6343], [9.6263, 54.6338], [9.6441, 54.6399], [9.6459, 54.6378], [9.6529, 54.6368], [9.657, 54.6327], [9.6629, 54.6312], [9.667, 54.6281], [9.6699, 54.6283], [9.6703, 54.6249], [9.6874, 54.6304], [9.6963, 54.6245], [9.6948, 54.6183], [9.7011, 54.6132], [9.6962, 54.6101], [9.6933, 54.6125], [9.6904, 54.6116], [9.6867, 54.6085], [9.6897, 54.6038], [9.6826, 54.6007], [9.6881, 54.599], [9.6857, 54.5943], [9.6911, 54.5913], [9.695, 54.591], [9.6965, 54.5932], [9.7065, 54.5957], [9.7101, 54.5935], [9.7148, 54.5931], [9.7169, 54.5948], [9.7232, 54.5928], [9.7241, 54.587], [9.718, 54.585], [9.7195, 54.5831], [9.7159, 54.5817], [9.7186, 54.5783], [9.7162, 54.5746], [9.7194, 54.5694], [9.7125, 54.5655], [9.7227, 54.5599], [9.7218, 54.5544], [9.7265, 54.5521], [9.726, 54.5492], [9.7289, 54.5497], [9.7322, 54.5478], [9.7413, 54.5402], [9.7412, 54.5375], [9.7374, 54.5357], [9.7389, 54.5321], [9.7373, 54.5303], [9.7211, 54.5299], [9.718, 54.5286], [9.714, 54.5187], [9.7119, 54.5183], [9.7024, 54.5179], [9.6932, 54.5224], [9.6731, 54.5153], [9.6439, 54.5155], [9.6344, 54.511], [9.6252, 54.5159], [9.6159, 54.5159], [9.616, 54.5236], [9.6035, 54.5269], [9.6036, 54.5282], [9.5986, 54.5282], [9.5927, 54.526], [9.5916, 54.5342], [9.5941, 54.5354], [9.5869, 54.5374], [9.5917, 54.5454], [9.5849, 54.5459], [9.576, 54.544], [9.5757, 54.5422], [9.5679, 54.5444], [9.5598, 54.5417], [9.5487, 54.5438], [9.546, 54.5413], [9.5472, 54.5402], [9.5434, 54.5391], [9.5456, 54.5394], [9.5445, 54.5367], [9.5399, 54.5357], [9.5364, 54.5393], [9.538, 54.5414], [9.5313, 54.5449], [9.5347, 54.5467], [9.5286, 54.5467], [9.5291, 54.5454], [9.5263, 54.5447], [9.5154, 54.5442], [9.5127, 54.5454], [9.5123, 54.5485], [9.5079, 54.549], [9.5054, 54.5526], [9.4992, 54.5549], [9.4941, 54.5647], [9.4899, 54.5617], [9.4798, 54.5643], [9.4824, 54.5965], [9.472, 54.5981], [9.4581, 54.5978], [9.4566, 54.6104], [9.4594, 54.6117], [9.4708, 54.6073], [9.4856, 54.6099], [9.491, 54.6094], [9.5065, 54.6153], [9.5059, 54.6205], [9.4983, 54.6206], [9.4995, 54.6246], [9.5109, 54.6234], [9.5116, 54.6258], [9.5009, 54.644], [9.4923, 54.6453], [9.4968, 54.6488], [9.4947, 54.6503], [9.493, 54.6494], [9.4844, 54.656], [9.4759, 54.6758], [9.5057, 54.6693], [9.5166, 54.6771], [9.5156, 54.6792], [9.5206, 54.6786], [9.5256, 54.6821], [9.5302, 54.683], [9.5301, 54.6842], [9.5359, 54.6846], [9.5297, 54.6703], [9.5299, 54.6676], [9.5328, 54.6672], [9.5328, 54.6652], [9.537, 54.6626], [9.5314, 54.6618], [9.5305, 54.6595], [9.5377, 54.6598], [9.5411, 54.6518], [9.5499, 54.6507], [9.5485, 54.6478], [9.5507, 54.6447], [9.5471, 54.6401], [9.5508, 54.6367], [9.5557, 54.6361]]]}'},
                       {u'key': u'spatial_text', u'value': u'Amt S\xfcdangeln'},
                       {u'key': u'spatial_uri',
                        u'value': u'http://dcat-ap.de/def/politicalGeocoding/regionalKey/010595987'},
                       {u'key': u'subject_text', u'value': u'Brosch\xfcre'},
                       {u'key': u'temporal_end', u'value': u'2020-05-31T00:00:00'},
                       {u'key': u'temporal_start', u'value': u'2020-05-01T00:00:00'}],
            'groups': [],
            'id': u'ff55a3ee-6dcd-4f76-b5a3-08055d5241f4',
            'is_new': True,
            'isopen': True,
            'language': u'http://publications.europa.eu/resource/authority/language/DEU',
            'license_id': u'http://dcat-ap.de/def/licenses/dl-zero-de/2.0',
            'license_title': u'Datenlizenz Deutschland \u2013 Zero \u2013 Version 2.0',
            'license_url': u'https://www.govdata.de/dl-de/zero-2-0',
            'maintainer': None,
            'maintainer_email': None,
            'metadata_created': '2020-05-14T12:34:05.551655',
            'metadata_modified': '2020-05-14T12:34:20.551455',
            'name': u'test-thumbnail',
            'notes': u'Test-Package f\xfcr Thumbnail-Gernerierung',
            'num_resources': 1,
            'num_tags': 0,
            'organization': {u'approval_status': u'approved',
                             u'created': '2019-07-29T08:11:32.697127',
                             u'description': u'',
                             u'id': u'63c87e74-60a9-4a4a-a980-d7983c47f92b',
                             u'image_url': u'',
                             u'is_organization': True,
                             u'name': u'test-organisation',
                             u'revision_id': u'3040af6c-d3f6-462d-b48a-329d63e17a28',
                             u'state': u'active',
                             u'title': u'Test-Organisation',
                             u'type': u'organization'},
            'owner_org': u'63c87e74-60a9-4a4a-a980-d7983c47f92b',
            'private': False,
            'relationships_as_object': [],
            'relationships_as_subject': [],
            'resources': [{u'cache_last_updated': None,
                           u'cache_url': None,
                           u'created': '2020-05-14T12:34:19.974216',
                           u'datastore_active': False,
                           u'description': u'',
                           u'format': u'PDF',
                           u'hash': u'66123edf64fabf1c073fc45478bf4a57',
                           u'hash_algorithm': u'http://dcat-ap.de/def/hashAlgorithms/md/5',
                           u'id': u'3ec53c20-f038-4ad6-a9fd-265cbe6faa27',
                           u'last_modified': '2020-05-14T12:34:19.817460',
                           u'mimetype': u'application/pdf',
                           u'mimetype_inner': None,
                           u'name': u'Checkliste-Barrierefreies-PDF.pdf',
                           u'number_of_pages': u'3',
                           u'package_id': u'ff55a3ee-6dcd-4f76-b5a3-08055d5241f4',
                           u'position': 0,
                           u'resource_type': None,
                           u'revision_id': u'efba6d3b-6204-4872-b6d1-a9e7b6d05a35',
                           u'size': 112437L,
                           u'state': u'active',
                           u'url': u'http://192.168.152.133:5000/dataset/ff55a3ee-6dcd-4f76-b5a3-08055d5241f4/resource/3ec53c20-f038-4ad6-a9fd-265cbe6faa27/download/checkliste-barrierefreies-pdf.pdf',
                           u'url_type': u'upload'}],
            'revision_id': u'cdedc6a9-92d9-4a9a-9511-12c2458cbfe5',
            'state': u'draft',
            'subject': u'http://transparenz.schleswig-holstein.de/informationsgegenstand#Broschuere',
            'tags': [],
            'title': u'Test Thumbnail',
            'type': u'dataset',
            'url': None,
            'version': None
        }


class WithAfterCreateDataAPI(object):

    def setUp(self):
        config.update({
            'ckan.thumbnail.size.width': 410,
            'ckan.storage_path': temp_path,
        })

        self.resource = {
            u'cache_last_updated': None,
            u'cache_url': None,
            u'created': '2020-05-18T12:06:59.559870',
            u'datastore_active': False,
            u'description': u'',
            u'format': u'PDF',
            u'hash': u'',
            u'id': u'341d8f18-00fc-4cd8-b6b1-0fc68f6b1c2e',
            u'last_modified': '2020-05-18T12:06:59.487842',
            u'mimetype': u'application/pdf',
            u'mimetype_inner': None,
            u'name': None,
            u'package_id': u'18eab091-64ce-44ad-b1cb-c8801017ce90',
            u'position': 0,
            u'resource_type': None,
            u'revision_id': u'5cdf9119-e88d-4a7e-a737-6b3f8c2b3877',
            u'size': 222997L,
            u'state': u'active',
            u'url': u'http://192.168.152.133:5000/dataset/18eab091-64ce-44ad-b1cb-c8801017ce90/resource/341d8f18-00fc-4cd8-b6b1-0fc68f6b1c2e/download/manual.pdf',
            u'url_type': u'upload'
        }

        self.resources = [{
            u'cache_last_updated': None,
            u'cache_url': None,
            u'created': '2020-05-18T12:06:59.559870',
            u'datastore_active': False,
            u'description': u'',
            u'format': u'PDF',
            u'hash': u'',
            u'id': u'341d8f18-00fc-4cd8-b6b1-0fc68f6b1c2e',
            u'last_modified': '2020-05-18T12:06:59.487842',
            u'mimetype': u'application/pdf',
            u'mimetype_inner': None,
            u'name': None,
            u'package_id': u'18eab091-64ce-44ad-b1cb-c8801017ce90',
            u'position': 0,
            u'resource_type': None,
            u'revision_id': u'5cdf9119-e88d-4a7e-a737-6b3f8c2b3877',
            u'revision_timestamp': u'2020-05-18T12:06:59.538388',
            u'size': 222997L,
            u'state': u'active',
            u'url': u'http://192.168.152.133:5000/dataset/18eab091-64ce-44ad-b1cb-c8801017ce90/resource/341d8f18-00fc-4cd8-b6b1-0fc68f6b1c2e/download/manual.pdf',
            u'url_type': u'upload'
        }]

        self.resources_second_call = [
            {
                u'cache_last_updated': None,
                u'cache_url': None,
                u'created': '2020-05-18T12:24:19.871546',
                u'datastore_active': False,
                u'description': u'',
                u'format': u'PDF',
                u'hash': u'f6c4aea4feff08461c5847788ec58c16',
                u'hash_algorithm': u'http://dcat-ap.de/def/hashAlgorithms/md/5',
                u'id': u'ddda4166-6618-4708-96ed-edb000096b58',
                u'last_modified': '2020-05-18T12:24:19.801966',
                u'mimetype': u'application/pdf',
                u'mimetype_inner': None,
                u'name': None,
                u'number_of_pages': u'11',
                u'package_id': u'941e2cc8-491c-48c5-8007-8a99041e230d',
                u'position': 0,
                u'resource_type': None,
                u'revision_id': u'60174ab3-419c-48dc-a56a-2bb633bbe6cb',
                u'revision_timestamp': u'2020-05-18T12:24:20.307640',
                u'size': 222997L,
                u'state': u'active',
                u'url': u'http://192.168.152.133:5000/dataset/941e2cc8-491c-48c5-8007-8a99041e230d/resource/ddda4166-6618-4708-96ed-edb000096b58/download/manual.pdf',
                u'url_type': u'upload'},
            {
                u'cache_last_updated': None,
                u'cache_url': None,
                u'created': '2020-05-18T12:26:24.185953',
                u'datastore_active': False,
                u'description': u'',
                u'format': u'PDF',
                u'hash': u'',
                u'id': u'8697b2f0-27b0-43ff-acfc-b7a1803db3b7',
                u'last_modified': '2020-05-18T12:26:24.113533',
                u'mimetype': u'application/pdf',
                u'mimetype_inner': None,
                u'name': None,
                u'package_id': u'941e2cc8-491c-48c5-8007-8a99041e230d',
                u'position': 1,
                u'resource_type': None,
                u'revision_id': u'3225d910-6a0d-48c9-8bb8-a362c7c94d59',
                u'revision_timestamp': u'2020-05-18T12:26:24.163859',
                u'size': 222997L,
                u'state': u'active',
                u'url': u'http://192.168.152.133:5000/dataset/941e2cc8-491c-48c5-8007-8a99041e230d/resource/8697b2f0-27b0-43ff-acfc-b7a1803db3b7/download/manual.pdf',
                u'url_type': u'upload'
            }
        ]

        self.context = {
            'package': Mock(
                id=u'18eab091-64ce-44ad-b1cb-c8801017ce90',
                is_private=False,
                private=False,
                type=u'dataset',
                url=None,
            ),
            'resources': [
                Mock(
                    id=u'341d8f18-00fc-4cd8-b6b1-0fc68f6b1c2e',
                    url_type=u'upload',
                )
            ]
        }

        self.package_dict = {
            'author': None,
            'author_email': None,
            'creator_user_id': u'ff8d002d-3908-45e5-ba7b-445381860957',
            'extras': [{u'key': u'issued', u'value': u'2019-07-07T00:00:00'},
                       {u'key': u'licenseAttributionByText', u'value': u''},
                       {u'key': u'subject_text', u'value': u'Verwaltungsvorschrift'}],
            'groups': [],
            'id': u'18eab091-64ce-44ad-b1cb-c8801017ce90',
            'is_new': False,
            'isopen': True,
            'language': u'http://publications.europa.eu/resource/authority/language/DEU',
            'license_id': u'http://dcat-ap.de/def/licenses/dl-zero-de/2.0',
            'license_title': u'Datenlizenz Deutschland \u2013 Zero \u2013 Version 2.0',
            'license_url': u'https://www.govdata.de/dl-de/zero-2-0',
            'maintainer': None,
            'maintainer_email': None,
            'metadata_created': '2020-05-18T12:06:59.137351',
            'metadata_modified': '2020-05-18T12:07:00.060791',
            'name': u'test-resource1',
            'notes': u'Testdatensatz aus Skript',
            'num_resources': 1,
            'num_tags': 0,
            'organization': {u'approval_status': u'approved',
                             u'created': '2019-07-29T08:11:32.697127',
                             u'description': u'',
                             u'id': u'63c87e74-60a9-4a4a-a980-d7983c47f92b',
                             u'image_url': u'',
                             u'is_organization': True,
                             u'name': u'test-organisation',
                             u'revision_id': u'3040af6c-d3f6-462d-b48a-329d63e17a28',
                             u'state': u'active',
                             u'title': u'Test-Organisation',
                             u'type': u'organization'},
            'owner_org': u'63c87e74-60a9-4a4a-a980-d7983c47f92b',
            'private': False,
            'relationships_as_object': [],
            'relationships_as_subject': [],
            'resources': [{u'cache_last_updated': None,
                           u'cache_url': None,
                           u'created': '2020-05-18T12:06:59.559870',
                           u'datastore_active': False,
                           u'description': u'',
                           u'format': u'PDF',
                           u'hash': u'f6c4aea4feff08461c5847788ec58c16',
                           u'hash_algorithm': u'http://dcat-ap.de/def/hashAlgorithms/md/5',
                           u'id': u'341d8f18-00fc-4cd8-b6b1-0fc68f6b1c2e',
                           u'last_modified': '2020-05-18T12:06:59.487842',
                           u'mimetype': u'application/pdf',
                           u'mimetype_inner': None,
                           u'name': None,
                           u'number_of_pages': u'11',
                           u'package_id': u'18eab091-64ce-44ad-b1cb-c8801017ce90',
                           u'position': 0,
                           u'resource_type': None,
                           u'revision_id': u'33c0df08-52cc-4774-b8d2-b283038b2891',
                           u'size': 222997L,
                           u'state': u'active',
                           u'url': u'http://192.168.152.133:5000/dataset/18eab091-64ce-44ad-b1cb-c8801017ce90/resource/341d8f18-00fc-4cd8-b6b1-0fc68f6b1c2e/download/manual.pdf',
                           u'url_type': u'upload'}],
            'revision_id': u'81152f7d-b942-42db-b1f1-f9e61cdfc43f',
            'state': u'active',
            'subject': u'http://transparenz.schleswig-holstein.de/informationsgegenstand#Verwaltungsvorschrift',
            'tags': [],
            'title': u'test resource',
            'type': u'dataset',
            'url': None,
            'version': None
        }

        self.package_dict_second_call = {
            'author': None,
            'author_email': None,
            'creator_user_id': u'ff8d002d-3908-45e5-ba7b-445381860957',
            'extras': [{u'key': u'issued', u'value': u'2019-07-07T00:00:00'},
                       {u'key': u'licenseAttributionByText', u'value': u''},
                       {u'key': u'subject_text', u'value': u'Verwaltungsvorschrift'}],
            'groups': [],
            'id': u'941e2cc8-491c-48c5-8007-8a99041e230d',
            'is_new': False,
            'isopen': True,
            'language': u'http://publications.europa.eu/resource/authority/language/DEU',
            'license_id': u'http://dcat-ap.de/def/licenses/dl-zero-de/2.0',
            'license_title': u'Datenlizenz Deutschland \u2013 Zero \u2013 Version 2.0',
            'license_url': u'https://www.govdata.de/dl-de/zero-2-0',
            'maintainer': None,
            'maintainer_email': None,
            'metadata_created': '2020-05-18T12:24:19.451803',
            'metadata_modified': '2020-05-18T12:26:24.637389',
            'name': u'test-resource3',
            'notes': u'Testdatensatz aus Skript',
            'num_resources': 2,
            'num_tags': 0,
            'organization': {u'approval_status': u'approved',
                             u'created': '2019-07-29T08:11:32.697127',
                             u'description': u'',
                             u'id': u'63c87e74-60a9-4a4a-a980-d7983c47f92b',
                             u'image_url': u'',
                             u'is_organization': True,
                             u'name': u'test-organisation',
                             u'revision_id': u'3040af6c-d3f6-462d-b48a-329d63e17a28',
                             u'state': u'active',
                             u'title': u'Test-Organisation',
                             u'type': u'organization'},
            'owner_org': u'63c87e74-60a9-4a4a-a980-d7983c47f92b',
            'private': False,
            'relationships_as_object': [],
            'relationships_as_subject': [],
            'resources': [
                {
                    u'cache_last_updated': None,
                    u'cache_url': None,
                    u'created': '2020-05-18T12:24:19.871546',
                    u'datastore_active': False,
                    u'description': u'',
                    u'format': u'PDF',
                    u'hash': u'f6c4aea4feff08461c5847788ec58c16',
                    u'hash_algorithm': u'http://dcat-ap.de/def/hashAlgorithms/md/5',
                    u'id': u'ddda4166-6618-4708-96ed-edb000096b58',
                    u'last_modified': '2020-05-18T12:24:19.801966',
                    u'mimetype': u'application/pdf',
                    u'mimetype_inner': None,
                    u'name': None,
                    u'number_of_pages': u'11',
                    u'package_id': u'941e2cc8-491c-48c5-8007-8a99041e230d',
                    u'position': 0,
                    u'resource_type': None,
                    u'revision_id': u'60174ab3-419c-48dc-a56a-2bb633bbe6cb',
                    u'size': 222997L,
                    u'state': u'active',
                    u'url': u'http://192.168.152.133:5000/dataset/941e2cc8-491c-48c5-8007-8a99041e230d/resource/ddda4166-6618-4708-96ed-edb000096b58/download/manual.pdf',
                    u'url_type': u'upload'
                },
                {
                    u'cache_last_updated': None,
                    u'cache_url': None,
                    u'created': '2020-05-18T12:26:24.185953',
                    u'datastore_active': False,
                    u'description': u'',
                    u'format': u'PDF',
                    u'hash': u'f6c4aea4feff08461c5847788ec58c16',
                    u'hash_algorithm': u'http://dcat-ap.de/def/hashAlgorithms/md/5',
                    u'id': u'8697b2f0-27b0-43ff-acfc-b7a1803db3b7',
                    u'last_modified': '2020-05-18T12:26:24.113533',
                    u'mimetype': u'application/pdf',
                    u'mimetype_inner': None,
                    u'name': None,
                    u'number_of_pages': u'11',
                    u'package_id': u'941e2cc8-491c-48c5-8007-8a99041e230d',
                    u'position': 1,
                    u'resource_type': None,
                    u'revision_id': u'c9157e0f-4516-462e-9fb2-ebfe51d17b82',
                    u'size': 222997L,
                    u'state': u'active',
                    u'url': u'http://192.168.152.133:5000/dataset/941e2cc8-491c-48c5-8007-8a99041e230d/resource/8697b2f0-27b0-43ff-acfc-b7a1803db3b7/download/manual.pdf',
                    u'url_type': u'upload'
                }
            ],
            'revision_id': u'68008d04-edcb-4040-bcec-b327ee39cdcc',
            'state': u'active',
            'subject': u'http://transparenz.schleswig-holstein.de/informationsgegenstand#Verwaltungsvorschrift',
            'tags': [],
            'thumbnail': u'thumbnail_picture_35c5b0113d495444a843162e72fa53.jpg',
            'title': u'test resource',
            'type': u'dataset',
            'url': None,
            'version': None
        }
